# BaseIdTableIdOrNameBody1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**fields** | **dict(str, object)** | Create a single record | [optional] 
**records** | [**list[BaseIdtableIdOrNameRecords1]**](BaseIdtableIdOrNameRecords1.md) | Create multiple records (up to 10) | [optional] 
**return_fields_by_field_id** | **bool** | Return fields keyed by field ID instead of name | [optional] [default to False]
**typecast** | **bool** | Attempt to convert string values to appropriate types | [optional] [default to False]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

